Module: Cucumber
- Defined in:
- lib/cucumber/query.rb,
lib/cucumber/repository.rb
Overview
Given one Cucumber Message, find another.
Queries can be made while the test run is incomplete - and this will naturally return incomplete results see Cucumber Messages - Message Overview
Defined Under Namespace
Classes: Query, Repository